kwimage.algo package
====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   kwimage.algo._nms_backend

Submodules
----------

.. toctree::
   :maxdepth: 4

   kwimage.algo.algo_nms

Module contents
---------------

.. automodule:: kwimage.algo
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
